AlignOffset Example
===============================================================================

:download:`align_offset.enaml <../../../examples/layout/basic/align_offset.enaml>`

.. literalinclude:: ../../../examples/layout/basic/align_offset.enaml
    :language: python

::

 $ enaml-run align_offset.enaml

.. image:: images/align_offset.png
